::-------------------------------------------------------------------------------
:: THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
:: IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
:: FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
:: AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
:: LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
:: OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
:: SOFTWARE.
::-------------------------------------------------------------------------------
:: Command line tool that combines bitmap2tga and GCBanner to directly
:: convert a 96x32 bitmap to a version 1 Gamecube banner file (.bnr)
::
:: Usage: bitmap2bnr.cmd [BITMAP] [BNR]
:: Supported bitmap formats: bmp, gif, exif, jpg, png and tiff
::
:: Script created by makeo
::
:: Included binaries:
:: GCBanner v0.3 by loser
:: bitmap2tga by makeo (Requires .Net Framework 3 or higher)
::-------------------------------------------------------------------------------

@echo off
IF NOT EXIST "%~dp0\bin\bitmap2tga.exe" (GOTO ERR_BIN)
IF NOT EXIST "%~dp0\bin\GCBanner.exe" (GOTO ERR_BIN)
GOTO M0
:ERR_BIN
  ECHO [Error] bin folder with bitmap2tga.exe and GCBanner.exe not found
  GOTO END
:M0

IF "%~1"=="" (GOTO ERR_USAGE)
IF "%~2"=="" (GOTO ERR_USAGE)
GOTO M1
:ERR_USAGE
  ECHO [Error] Invalid usage
  ECHO Command syntax: %~nx0 [BITMAP] [BNR]
  GOTO END
:M1

IF NOT EXIST "%~1" (
ECHO [Error] Bitmap does not exist
GOTO END
)

IF NOT EXIST "%~dp0\tmp\" (
  MKDIR "%~dp0\tmp\"
  ECHO Created tmp directory
)

IF EXIST "%~dp0\tmp\tmp.tga" (
  DEL /f "%~dp0\tmp\tmp.tga"
  ECHO Removed old tmp.tga
)

ECHO Creating TGA image using bitmap2tga
"%~dp0\bin\bitmap2tga.exe" "%~1" "%~dp0\tmp\tmp.tga"

IF NOT EXIST "%~dp0\tmp\tmp.tga" (
  ECHO [Error] Unable to create TGA image
  GOTO END
)

ECHO Created tmp.tga

ECHO Creating banner ^(bnr^) file using GCBanner
("%~dp0\bin\GCBanner.exe" b "%~2" "%~dp0\tmp\tmp.tga")

IF NOT EXIST "%~2" (
ECHO [Error] Failed to create banner ^(bnr^) file
GOTO END
)

ECHO Created banner ^(bnr^) file

:END